"""A code component."""

import json
from typing import Dict

from pynecone import utils
from pynecone.components.component import Component
from pynecone.components.libs.chakra import ChakraComponent
from pynecone.components.tags import Tag
from pynecone.var import Var


class CodeBlock(Component):
    """A code block."""

    library = "react-syntax-highlighter"

    tag = "Prism"

    # The language to use.
    language: Var[str]

    # If this is enabled line numbers will be shown next to the code block.
    show_line_numbers: Var[bool]

    # The starting line number to use.
    starting_line_number: Var[int]

    # Whether to wrap long lines.
    wrap_long_lines: Var[bool]

    # A custom style for the code block.
    custom_style: Var[Dict[str, str]]

    # Props passed down to the code tag.
    code_tag_props: Var[Dict[str, str]]

    @classmethod
    def create(cls, code: str, *args, **attrs):
        """Create a text component.

        Args:
            code: The code to display.
            **attrs: The attributes to pass to the component.

        Returns:
            The text component.
        """
        code = utils.wrap(json.dumps(code), "{")
        custom_style = attrs.get("custom_style", {})
        for key, value in attrs.items():
            if key not in cls.get_fields():
                custom_style[key] = value
        return super().create(
            code,
            # style=Var.create("xcode"),
            *args,
            **attrs,
        )

    def _add_style(self, style):
        self.custom_style = self.custom_style or {}
        self.custom_style.update(style)  # type: ignore


class Code(ChakraComponent):
    """Used to display inline code."""

    tag = "Code"
