"""A checkbox component."""

from typing import Any, Tuple

from pynecone.components.libs.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.event import EventChain
from pynecone.var import Var


class Checkbox(ChakraComponent, ControlledMixin):
    """The Checkbox component is used in forms when a user needs to select multiple values from several options."""

    tag = "Checkbox"

    # Color scheme for checkbox.
    color_scheme: Var[str]

    # "sm" | "md" | "lg"
    size: Var[str]

    # If true, the checkbox will be checked.
    is_checked: Var[bool]

    # If true, the checkbox will be disabled
    is_disabled: Var[bool]

    # If true and is_disabled is passed, the checkbox will remain tabbable but not interactive
    is_focusable: Var[bool]

    # If true, the checkbox will be indeterminate. This only affects the icon shown inside checkbox and does not modify the is_checked var.
    is_indeterminate: Var[bool]

    # If true, the checkbox is marked as invalid. Changes style of unchecked state.
    is_invalid: Var[bool]

    # If true, the checkbox will be readonly
    is_read_only: Var[bool]

    # If true, the checkbox input is marked as required, and required attribute will be added
    is_required: Var[bool]

    # The name of the input field in a checkbox (Useful for form submission).
    name: Var[str]

    # The callback invoked when the checkbox is focused
    on_focus: EventChain

    # The spacing between the checkbox and its label text (0.5rem)
    spacing: Var[str]

    def _get_controlled_var(self) -> Var:
        return self.is_checked

    def _get_handler_args(self) -> Tuple[Tuple[str, Any], ...]:
        return ((self.is_checked.name, "e.target.checked"),)


class CheckboxGroup(ChakraComponent):
    """A group of checkboxes."""

    tag = "CheckboxGroup"

    # The initial value of the checkbox group
    default_value: Var[str]

    # If true, all wrapped checkbox inputs will be disabled
    is_disabled: Var[bool]

    # If true, input elements will receive checked attribute instead of isChecked. This assumes, you're using native radio inputs
    is_native: Var[bool]

    # The value of the checkbox group
    value: Var[str]
