"""A radio component."""


from typing import Any, Tuple

from pynecone.components.libs.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.components.typography.text import Text
from pynecone.var import Var


class RadioGroup(ChakraComponent, ControlledMixin):
    """A grouping of individual radio options."""

    tag = "RadioGroup"

    # State var to bind the the input.
    value: Var[int]

    def _get_local_args(self) -> Tuple[str, ...]:
        return ("val",)

    def _get_handler_args(self) -> Tuple[Tuple[str, Any], ...]:
        return ((self.value.name, "val"),)


class Radio(Text):
    """Radios are used when only one choice may be selected in a series of options."""

    tag = "Radio"

    # Value of button.
    value: Var[int]

    # The color scheme.
    color_scheme: Var[str]

    # If true, the radio will be initially checked.
    default_checked: Var[bool]

    # If true, the radio will be checked. You'll need to pass onChange to update its value (since it is now controlled)
    is_checked: Var[bool]

    # If true, the radio will be disabled.
    is_disabled: Var[bool]

    # If true, the radio button will be invalid. This also sets `aria-invalid` to true.
    is_invalid: Var[bool]

    # If true, the radio will be read-only
    is_read_only: Var[bool]

    # If true, the radio button will be required. This also sets `aria-required` to true.
    is_required: Var[bool]
