"""A switch component."""
from typing import Any, Tuple

from pynecone.components.libs.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.event import EventChain
from pynecone.var import Var


class Switch(ChakraComponent, ControlledMixin):
    """Togglable switch component."""

    tag = "Switch"

    # If true, the switch will be checked. You'll need to pass onChange to update its value (since it is now controlled)
    is_checked: Var[bool]

    # If true, the switch will be disabled
    is_disabled: Var[bool]

    # If true and isDisabled is passed, the switch will remain tabbable but not interactive
    is_focusable: Var[bool]

    # If true, the switch is marked as invalid. Changes style of unchecked state.
    is_invalid: Var[bool]

    # If true, the switch will be readonly
    is_read_only: Var[bool]

    # If true, the switch will be required
    is_required: Var[bool]

    # The name of the input field in a switch (Useful for form submission).
    name: Var[str]

    # The callback invoked when the switch is focused
    on_focus: EventChain

    # The spacing between the switch and its label text (0.5rem)
    spacing: Var[str]

    # The placeholder text.
    placeholder: Var[str]

    def _get_controlled_var(self) -> Var:
        return self.is_checked

    def _get_handler_args(self) -> Tuple[Tuple[str, Any], ...]:
        return ((self.is_checked.name, "e.target.checked"),)
