"""A textarea component."""

from pynecone import utils
from pynecone.components.libs.chakra import ChakraComponent
from pynecone.components.mixins import ControlledMixin
from pynecone.components.tags import Tag
from pynecone.var import Var


class TextArea(ChakraComponent, ControlledMixin):
    """A text area component."""

    tag = "Textarea"

    # State var to bind the the input.
    value: Var[str]

    # The placeholder text.
    placeholder: Var[str]

    # The type of input.
    type_: Var[str] = "text"  # type: ignore

    # The border color when the input is invalid.
    error_border_color: Var[str]

    # The border color when the input is focused.
    focus_border_color: Var[str]

    # If true, the form control will be disabled.
    is_disabled: Var[bool]

    # If true, the form control will be invalid.
    is_invalid: Var[bool]

    # If true, the form control will be readonly.
    is_read_only: Var[bool]

    # If true, the form control will be required.
    is_required: Var[bool]

    # "outline" | "filled" | "flushed" | "unstyled"
    variant: Var[str]

    @property
    def default_placeholder(self) -> str:
        """Get the default placeholder text.

        Returns:
            The default placeholder text.
        """
        return utils.to_title(self.value.name)

    def _render(self) -> Tag:
        return (
            super()
            ._render()
            .add_attrs(
                placeholder=self.placeholder
                if self.placeholder is not None
                else self.default_placeholder,
                type=self.type_,
            )
        )
