"""Component for displaying a plotly graph."""

from typing import Dict, Union

from plotly.graph_objects import Figure
from plotly.io import to_json

from pynecone.components.component import Component
from pynecone.components.tags import Tag
from pynecone.var import Var


class PlotlyLib(Component):
    """A component that wraps a plotly lib."""

    library = "react-plotly.js"


class Plotly(PlotlyLib):
    """Display a plotly graph."""

    tag = "Plot"

    data: Union[Figure, dict]

    layout: Var[Dict]

    width: Var[str]

    height: Var[str]

    autosize: Var[bool]

    use_resize_handler: bool = False

    def _get_imports(self):
        return {}

    def _get_custom_code(self) -> str:
        return """
import dynamic from 'next/dynamic'
const Plot = dynamic(() => import('react-plotly.js'), { ssr: false }); 
"""

    def _render(self) -> Tag:
        if isinstance(self.data, Figure):
            self.data = to_json(self.data)
            import json

            self.data = json.loads(self.data)["data"]

            if self.layout is None:
                if self.width is not None:
                    self.layout = {"width": self.width, "height": self.height}

            if self.autosize is not None and self.layout is not None:
                self.layout["autosize"] = self.autosize
            elif self.autosize is not None:
                self.layout = {"autosize": self.autosize}

        return super()._render()
