"""An image component."""
from __future__ import annotations

from pynecone.components.libs.chakra import ChakraComponent
from pynecone.components.tags import Tag
from pynecone.event import EventChain
from pynecone.var import Var


class Image(ChakraComponent):
    """The Image component is used to display images. Image composes Box so you can use all the style props and add responsive styles as well."""

    tag = "Image"

    # How to align the image within its bounds. It maps to css `object-position` property.
    align: Var[str]

    # The key used to set the crossOrigin on the HTMLImageElement into which the image will be loaded. This tells the browser to request cross-origin access when trying to download the image data.
    cross_origin: Var[str]

    # Fallback element to show if image is loading or image fails.
    fallback: Var[Tag]

    # Fallback image src to show if image is loading or image fails. Note 🚨: We recommend you use a local image
    fallback_src: Var[str]

    # How the image to fit within its bounds. It maps to css `object-fit` property.
    fit: Var[str]

    # The native HTML height attribute to the passed to the img
    html_height: Var[str]

    # The native HTML width attribute to the passed to the img
    html_width: Var[str]

    # If true, opt out of the fallbackSrc logic and use as img
    ignore_fallback: Var[bool]

    # "eager" | "lazy"
    loading: Var[str]

    # A callback for when there was an error loading the image src
    on_error: EventChain

    # A callback for when the image src has been loaded
    on_load: EventChain

    # The image src attribute
    src: Var[str]

    # The image srcset attribute
    src_set: Var[str]
